%global __requires_exclude ^%{_bindir}/coreutils$

Summary:A set of basic GNU tools commonly used in shell scripts
Name:		coreutils
Version:	9.4
Release:	4%{?dist}
License:	GPLv3+
Url:		https://www.gnu.org/software/coreutils/
Source0:	https://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.xz
Source1:    colorls.sh

Patch0001:  skip-some-tests-if-selinux-is-disabled.patch
Patch0002:  0001-CVE-2024-0684-split-do-not-shrink-hold-buffer.patch
Patch3000:  coreutils-9.4-systemd-coredump.patch 
Patch5000:  add-sm3sum-support.patch
Patch5001:  0001-fix-uname-processortype-error-for-loongarch64.patch

%ifarch loongarch64
BuildRequires:	attr, autoconf, automake, gcc, hostname, make, texinfo, libselinux-utils
%else
BuildRequires:	attr, autoconf, automake, gcc, hostname, make, strace, texinfo, libselinux-utils
%endif
BuildRequires:	gettext-devel, gmp-devel, libacl-devel, libattr-devel, libcap-devel, libselinux-devel, openssl-devel
# test-only dependencies
BuildRequires:	perl-interpreter, perl(FileHandle)
# needed by i18n test-cases
BuildRequires:	glibc-langpack-en
Provides: 	%{name}-common = %{version}-%{release}
Provides:	coreutils-full = %{version}-%{release}
Provides:	bundled(gnulib)
Provides:	/bin/cat, /bin/chmod, /bin/echo, /bin/ln, /bin/rm, /bin/touch

%description
The GNU Core Utilities are the basic file, shell and text manipulation utilities of the GNU operating system. 
These are the core utilities which are expected to exist on every operating system.



%prep
%autosetup -N

sed src/dircolors.hin \
        -e 's| 00;36$| 01;36|' \
        > DIR_COLORS

sed src/dircolors.hin \
        -e 's| 01;31$| 00;31|' \
        -e 's| 01;35$| 00;35|' \
        > DIR_COLORS.lightbgcolor

%autopatch -p1
find tests -name '*.sh' -perm 0644 -print -exec chmod 0755 '{}' '+'
autoreconf -fiv
%ifarch loongarch64
sed -i "/inotify-dir-recreate.sh/d" tests/local.mk
%endif



%build
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -fpic"
export ac_cv_func_lchmod="no"
export optflags="%{optflags} -D_GNU_SOURCE=1" 
mkdir -p separate && \
  (cd separate && ln -s ../configure || exit $?
  %configure --with-openssl \
             --cache-file=../config.cache \
             --enable-install-program=arch \
             --enable-no-install-program=kill,uptime \
             --with-tty-group \
             DEFAULT_POSIX2_VERSION=200112 alternative=199209 || :
  %make_build all V=1

  ln -fv ../lib/parse-datetime.{c,y} .
  )



%install
(cd separate && make DESTDIR=%buildroot install)
mkdir -p %buildroot/{%{_bindir},%{_sbindir}}
mv %buildroot/{%_bindir,%_sbindir}/chroot
%find_lang %name
grep LC_TIME %name.lang | cut -d'/' -f1-6 | sed -e 's/) /) %%dir /g' >>%name.lang

mkdir -p %buildroot%{_sysconfdir}/profile.d
install -p -c -m644 DIR_COLORS{,.lightbgcolor} %buildroot%{_sysconfdir}
install -p -c -m644 %{SOURCE1} %buildroot%{_sysconfdir}/profile.d/colorls.sh



%check
pushd separate
make check VERBOSE=yes
popd



%files -f %{name}.lang
%license COPYING
%doc ABOUT-NLS NEWS README THANKS TODO
%{_bindir}/*
%{_sbindir}/chroot
%dir %{_libexecdir}/coreutils
%{_libexecdir}/coreutils/*.so
%config(noreplace) %{_sysconfdir}/DIR_COLORS*
%config(noreplace) %{_sysconfdir}/profile.d/*
%{_infodir}/coreutils*
%exclude %{_infodir}/dir
%{_mandir}/man*/*



%changelog
* Tue Apr 2 2024 luffyluo <luffyluo@tencent.com> - 9.4-4
- Fix error changelog format

* Mon Mar 11 2024 Wenlong Zhang <zhangwenlong@loongson.cn> - 9.4-3
- add loongarch64 support for coreutils

* Mon Jan 29 2024 luffyluo <luffyluo@tencent.com> - 9.4-2
- Fix CVE-2024-0684

* Thu Jan 11 2024 Upgrade Robot <upbot@opencloudos.org> - 9.4-1
- Upgrade to version 9.4

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 9.3-2
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Jul 26 2023 Miaojun Dong <zoedong@tencent.com> - 9.3-1
- Bump version to 9.3

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 9.1-5
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 9.1-4
- Rebuilt for OpenCloudOS Stream 23

* Thu Feb 16 2023 Miaojun Dong <zoedong@tencent.com> - 9.1-3
- add support for sm3

* Wed Dec 7 2022 Zhao Zhen <jeremiazhao@tencent.com> - 9.1-2
- added some added bash configures

* Thu Apr 28 2022 Songqiao Tao <joeytao@tencent.com> - 9.1-1
- initial build
